@@ -21,7 +21,7 @@ cmake ${CMAKE_ARGS} .. \
       -DPYTHON_EXECUTABLE=$PYTHON \
       -DGENERATE_PYTHON_STUBS=$GENERATE_PYTHON_STUBS \
       -DNUMPY_INCLUDE_DIRS=$TARGET_NUMPY_INCLUDE_DIRS
-make -j1
+make -j$(($CPU_COUNT/2))
 make install
 
 if [[ $CONDA_BUILD_CROSS_COMPILATION == 1 ]]; then
